class C:
    x: int

    def __init__(self) -> None:
        self.x = int(0)  # noqa: UP018
